@@ -9,13 +9,15 @@
 #
 
 package Config::Model::Describe;
-$Config::Model::Describe::VERSION = '2.095';
+$Config::Model::Describe::VERSION = '2.096';
 use Carp;
 use strict;
 use warnings;
 
 use Config::Model::Exception;
 use Config::Model::ObjTreeScanner;
+use List::Util qw/max/;
+use utf8;
 
 sub new {
     bless {}, shift;
@@ -29,11 +31,15 @@ sub describe {
         || croak "describe: missing 'node' parameter";
     my $check = delete $args{check} || 'yes';
 
-    my $element = delete $args{element} ;        # optional
-    my $pattern = delete $args{pattern} ;        # optional
+    my $element    = delete $args{element} ;        # optional
+    my $pattern    = delete $args{pattern} ;        # optional
+    my $hide_empty = delete $args{hide_empty} // 0 ; # optional
+    my $verbose    = delete $args{verbose}    // 0 ; # optional
+
+    my $show_empty = ! $hide_empty ;
 
     my $tag_name = sub {
-        $_[1] .= ' /!\\' if $_[0]->has_warning;
+        $_[1] .= ' ⚠' if $_[0]->has_warning;
     };
 
     my $my_content_cb = sub {
@@ -47,6 +53,9 @@ sub describe {
         my ( $scanner, $data_r, $obj, $element, $index, $value_obj ) = @_;
 
         my $value = $value_obj->fetch( check => $check );
+
+        return unless $show_empty or (defined $value and length($value));
+
         $value = '"' . $value . '"' if defined $value and $value =~ /\s/;
 
         #print "DEBUG: std_cb on $element, idx $index, value $value\n";
@@ -61,7 +70,7 @@ sub describe {
         push @comment, 'mandatory' if $value_obj->mandatory;
 
         $tag_name->($value_obj,$element);
-        push @$data_r, [ $name, $value, $type, join( ', ', @comment ) ];
+        push @$data_r, [ $name, $type, $value, join( ', ', @comment ) ];
     };
 
     my $list_element_cb = sub {
@@ -78,8 +87,9 @@ sub describe {
             push @$data_r, [ $element, "<$class_name>", 'node list', "indexes: @show_keys" ];
         }
         else {
+            my @values = grep {  $show_empty or length } $list_obj->fetch_all_values( check => 'no' ) ;
             push @$data_r,
-                [ $element, join( ',', $list_obj->fetch_all_values( check => 'no' ) ), 'list', '' ];
+                [ $element, 'list', join( ',', @values ), '' ] if ($show_empty or @values);
         }
     };
 
@@ -88,7 +98,8 @@ sub describe {
 
         my $list_obj = $obj->fetch_element($element);
         $tag_name->($list_obj,$element);
-        push @$data_r, [ $element, join( ',', $list_obj->get_checked_list ), 'check_list', '' ];
+        my @checked = $list_obj->get_checked_list;
+        push @$data_r, [ $element, 'check_list', join( ',', @checked ), '' ] if $show_empty or @checked;
     };
 
     my $hash_element_cb = sub {
@@ -103,13 +114,13 @@ sub describe {
             my $class_name = $hash_obj->config_class_name;
             my @show_keys  = @keys ? map { qq("$_") } @keys : ('<empty>');
             my $show_str   = "keys: @show_keys";
-            push @$data_r, [ $element, "<$class_name>", 'node hash', $show_str ];
+            push @$data_r, [ $element, 'node hash', "<$class_name>", $show_str ];
         }
         elsif (@keys) {
             map { $scanner->scan_hash( $data_r, $obj, $element, $_ ) } @keys;
         }
         else {
-            push @$data_r, [ $element, "[empty hash]", 'value hash', "" ];
+            push @$data_r, [ $element, 'value hash', "[empty hash]",  "" ] if $show_empty;
         }
     };
 
@@ -120,7 +131,7 @@ sub describe {
         my $type = $obj->element_type($element);
 
         my $class_name = $next->config_class_name;
-        push @$data_r, [ $element, "<$class_name>", 'node', '' ];
+        push @$data_r, [ $element, 'node', "<$class_name>", '' ];
 
         #$ret .= ":$key" if $type eq 'list' or $type eq 'hash';
 
@@ -144,10 +155,7 @@ sub describe {
     # perform the scan
     my $view_scanner = Config::Model::ObjTreeScanner->new(@scan_args);
 
-    my $format = "%-12s %-12s %-12s %-35s\n";
-
-    my @ret = [qw/name value type comment/];
-
+    my @ret;
     if ( defined $element and $desc_node->has_element($element) ) {
         $view_scanner->scan_element( \@ret, $desc_node, $element );
     }
@@ -163,7 +171,31 @@ sub describe {
         $view_scanner->scan_node( \@ret, $desc_node );
     }
 
-    return join '', map { sprintf( $format, @$_ ) } @ret;
+    my @header = qw/name type value/;
+    my $name_length  = max map { length($_->[0]) } (@ret, \@header );
+    my $type_length  = max map { length($_->[1]) } (@ret, \@header );
+    my $value_length = max map { length($_->[2]) } (@ret, \@header );
+    my $sep_length = $name_length + $type_length + $value_length + 4 ;
+    my @format = ("%-${name_length}s", "%-${type_length}s", "%-${value_length}s") ;
+
+    my @show ;
+    if ($verbose) {
+        push @format, "%-35s";
+        @show = (
+            sprintf( join(" │ ", @format)."\n", qw/name type value comment/) ,
+            sprintf( join("─┼─", @format)."\n", '─' x $name_length,'─' x $type_length,'─' x $value_length,'─' x 20, ) ,
+            map { sprintf( join(" │ ", @format)."\n", @$_ ) } @ret
+        );
+    }
+    else {
+        @show = (
+            sprintf( join(" │ ", @format)."\n", qw/name type value/) ,
+            sprintf( join("─┼─", @format)."\n", '─' x $name_length,'─' x $type_length,'─' x $value_length ) ,
+            map { sprintf( join(" │ ", @format)."\n", @$_[0,1,2] ) } @ret
+        );
+    }
+
+    return join ('', @show );
 }
 
 1;
@@ -182,7 +214,7 @@ Config::Model::Describe - Provide a description of a node element
 
 =head1 VERSION
 
-version 2.095
+version 2.096
 
 =head1 SYNOPSIS
 
@@ -231,10 +263,10 @@ version 2.095
  print $root->describe ;
 
  ### prints
- # name         value        type         comment
- # foo          FOO          string
- # bar          [undef]      string
- # hash_of_nodes <Foo>        node hash    keys: "en" "fr"
+ # name          type       value          comment
+ # foo           string     FOO
+ # bar           string     [undef]
+ # hash_of_nodes node hash  <Foo>          keys: "en" "fr"
 
 =head1 DESCRIPTION
 
@@ -244,12 +276,12 @@ shows the content of a configuration node.
 
 For instance (as shown by C<fstab> example:
 
- name         value        type         comment
- fs_spec      [undef]      string       mandatory
- fs_vfstype   [undef]      enum         choice: auto davfs ext2 ext3 swap proc iso9660 vfat ignore, mandatory
- fs_file      [undef]      string       mandatory
- fs_freq      0            boolean
- fs_passno    0            integer
+ name         type         value        comment
+ fs_spec      string       [undef]      mandatory
+ fs_vfstype   enum         [undef]      choice: auto davfs ext2 ext3 swap proc iso9660 vfat ignore, mandatory
+ fs_file      string       [undef]      mandatory
+ fs_freq      boolean      0
+ fs_passno    integer      0
 
 This module is also used by the C<ll> command of L<Config::Model::TermUI>.
 
@@ -262,7 +294,7 @@ L<Config::Model::Node>.
 
 =head1 Methods
 
-=head2 describe(...)
+=head2 describe
 
 Return a description string.
 
@@ -285,6 +317,14 @@ Describe the element matching the regexp ref. Example:
 
  describe => ( pattern => qr/^foo/ )
 
+=item hide_empty
+
+Boolean. Whether to hide empty value (i.e. C<undef> or C<''>) or not. Default is false.
+
+=item verbose
+
+Boolean. Display more information with each element. Default is false.
+
 =back
 
 =head1 AUTHOR
