@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Exception;
-$Config::Model::Exception::VERSION = '2.095';
+$Config::Model::Exception::VERSION = '2.096';
 use warnings;
 use strict;
 use Data::Dumper;
@@ -44,6 +44,7 @@ has  object => ( is => 'rw', isa => 'Ref') ;
 has  info => (is => 'rw', isa =>'Str', default => '');
 has  message => (is => 'rw', isa =>'Str', default => '');
 has  error => (is => 'rw', isa =>'Str', default => '');
+has  trace => (is => 'rw', isa =>'Str', default => '');
 
 # without this overload, a test like if ($@) invokes '""' overload
 sub is_error { return ref ($_[0])}
@@ -61,7 +62,12 @@ sub error_or_msg {
 sub throw {
     my $class = shift;
     my $self = $class->new(@_);
-    $self->rethrow;
+    # when an exception is thrown, caught and rethrown, the first full
+    # trace (provided by longmess) is clobbered by a second, shorter
+    # trace (also provided by longmess). To avoid that, the first
+    # trace must be  stored.
+    $self->trace($trace ? longmess : '') ;
+    die $self;
 }
 
 sub rethrow {
@@ -70,8 +76,9 @@ sub rethrow {
 }
 
 sub full_msg_and_trace {
-    my $msg = shift->full_message;
-    $msg .= "Exception thrown ".longmess if $trace;
+    my $self = shift;
+    my $msg = $self->full_message;
+    $msg .= $self->trace;
     return $msg;
 }
 
@@ -93,19 +100,19 @@ sub full_message {
 }
 
 package Config::Model::Exception::Any;
-$Config::Model::Exception::Any::VERSION = '2.095';
+$Config::Model::Exception::Any::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception';
 
 package Config::Model::Exception::ModelDeclaration;
-$Config::Model::Exception::ModelDeclaration::VERSION = '2.095';
+$Config::Model::Exception::ModelDeclaration::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
 sub _desc {'configuration model declaration error' }
 
 package Config::Model::Exception::User ;
-$Config::Model::Exception::User::VERSION = '2.095';
+$Config::Model::Exception::User::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::Any';
 sub _desc {'user error' }
@@ -113,7 +120,7 @@ sub _desc {'user error' }
 
 ## old classes below
 package Config::Model::Exception::Syntax;
-$Config::Model::Exception::Syntax::VERSION = '2.095';
+$Config::Model::Exception::Syntax::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::Any';
 
@@ -134,7 +141,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::LoadData;
-$Config::Model::Exception::LoadData::VERSION = '2.095';
+$Config::Model::Exception::LoadData::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -158,7 +165,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::Model;
-$Config::Model::Exception::Model::VERSION = '2.095';
+$Config::Model::Exception::Model::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
@@ -191,7 +198,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::Load;
-$Config::Model::Exception::Load::VERSION = '2.095';
+$Config::Model::Exception::Load::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -220,7 +227,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::UnavailableElement;
-$Config::Model::Exception::UnavailableElement::VERSION = '2.095';
+$Config::Model::Exception::UnavailableElement::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -251,7 +258,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::AncestorClass;
-$Config::Model::Exception::AncestorClass::VERSION = '2.095';
+$Config::Model::Exception::AncestorClass::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -259,7 +266,7 @@ sub _desc { 'unknown ancestor class'}
 
 
 package Config::Model::Exception::ObsoleteElement;
-$Config::Model::Exception::ObsoleteElement::VERSION = '2.095';
+$Config::Model::Exception::ObsoleteElement::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -284,7 +291,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::UnknownElement;
-$Config::Model::Exception::UnknownElement::VERSION = '2.095';
+$Config::Model::Exception::UnknownElement::VERSION = '2.096';
 use Carp;
 
 use Mouse;
@@ -359,14 +366,14 @@ sub full_message {
 }
 
 package Config::Model::Exception::WarpError;
-$Config::Model::Exception::WarpError::VERSION = '2.095';
+$Config::Model::Exception::WarpError::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'warp error'}
 
 package Config::Model::Exception::Fatal;
-$Config::Model::Exception::Fatal::VERSION = '2.095';
+$Config::Model::Exception::Fatal::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::Any';
 
@@ -374,7 +381,7 @@ sub _desc { 'fatal error' }
 
 
 package Config::Model::Exception::UnknownId;
-$Config::Model::Exception::UnknownId::VERSION = '2.095';
+$Config::Model::Exception::UnknownId::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -408,7 +415,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::WrongValue;
-$Config::Model::Exception::WrongValue::VERSION = '2.095';
+$Config::Model::Exception::WrongValue::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -416,7 +423,7 @@ sub _desc { 'wrong value'};
 
 
 package Config::Model::Exception::WrongType;
-$Config::Model::Exception::WrongType::VERSION = '2.095';
+$Config::Model::Exception::WrongType::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -447,14 +454,14 @@ sub full_message {
 }
 
 package Config::Model::Exception::ConfigFile;
-$Config::Model::Exception::ConfigFile::VERSION = '2.095';
+$Config::Model::Exception::ConfigFile::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'error in configuration file' }
 
 package Config::Model::Exception::ConfigFile::Missing;
-$Config::Model::Exception::ConfigFile::Missing::VERSION = '2.095';
+$Config::Model::Exception::ConfigFile::Missing::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::ConfigFile';
 
@@ -471,14 +478,14 @@ sub full_message {
 }
 
 package Config::Model::Exception::Formula;
-$Config::Model::Exception::Formula::VERSION = '2.095';
+$Config::Model::Exception::Formula::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::Model';
 
 sub _desc { 'error in computation formula of the configuration model'}
 
 package Config::Model::Exception::Internal;
-$Config::Model::Exception::Internal::VERSION = '2.095';
+$Config::Model::Exception::Internal::VERSION = '2.096';
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
@@ -500,7 +507,7 @@ Config::Model::Exception - Exception mechanism for configuration model
 
 =head1 VERSION
 
-version 2.095
+version 2.096
 
 =head1 SYNOPSIS
 
