@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Node;
-$Config::Model::Node::VERSION = '2.095';
+$Config::Model::Node::VERSION = '2.096';
 use Mouse;
 with "Config::Model::Role::NodeLoader";
 
@@ -515,7 +515,7 @@ sub get_element_names {
     my $type       = $args{type};              # optional
     my $cargo_type = $args{cargo_type};        # optional
 
-    $self->init;
+    $self->init(check => $args{check});
 
     my @result;
 
@@ -1032,14 +1032,16 @@ sub load_data {
 
 sub dump_tree {
     my $self = shift;
-    $self->init;
+    my %args = @_;
+    $self->init(check => $args{check});
     my $dumper = Config::Model::Dumper->new;
     $dumper->dump_tree( node => $self, @_ );
 }
 
 sub migrate {
     my $self = shift;
-    $self->init;
+    my %args = @_;
+    $self->init(check => $args{check});
     Config::Model::Dumper->new->dump_tree( node => $self, mode => 'full', @_ );
 
     return $self->needs_save;
@@ -1047,14 +1049,16 @@ sub migrate {
 
 sub dump_annotations_as_pod {
     my $self = shift;
-    $self->init;
+    my %args = @_;
+    $self->init(check => $args{check});
     my $dumper = Config::Model::DumpAsData->new;
     $dumper->dump_annotations_as_pod( node => $self, @_ );
 }
 
 sub describe {
     my $self = shift;
-    $self->init;
+    my %args = @_;
+    $self->init(check => $args{check});
 
     my $descriptor = Config::Model::Describe->new;
     $descriptor->describe( node => $self, @_ );
@@ -1062,14 +1066,16 @@ sub describe {
 
 sub report {
     my $self = shift;
-    $self->init;
+    my %args = @_;
+    $self->init(check => $args{check});
     my $reporter = Config::Model::Report->new;
     $reporter->report( node => $self );
 }
 
 sub audit {
     my $self = shift;
-    $self->init;
+    my %args = @_;
+    $self->init(check => $args{check});
     my $reporter = Config::Model::Report->new;
     $reporter->report( node => $self, audit => 1 );
 }
@@ -1209,7 +1215,7 @@ Config::Model::Node - Class for configuration tree node
 
 =head1 VERSION
 
-version 2.095
+version 2.096
 
 =head1 SYNOPSIS
 
