@@ -8,13 +8,14 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::SimpleUI;
-$Config::Model::SimpleUI::VERSION = '2.095';
+$Config::Model::SimpleUI::VERSION = '2.096';
 use Carp;
 use 5.010;
 use strict;
 use warnings;
 use open      qw(:std :utf8);    # undeclared streams in UTF-8
 use Encode qw(decode_utf8);
+use Regexp::Common qw/delimited/;
 
 my $syntax = '
 cd <elt> cd <elt:key>, cd - , cd !
@@ -29,8 +30,11 @@ delete elt
    -> like reset, delete a value (set to undef)
 display elt elt:key
    -> display a value
-ls -> show elements of current node
-ll -> show elements of current node and their value
+ls -> show elements of current node (args: filter pattern)
+ll [-nz] [-v] [ element | pattern ]
+   -> show elements of current node and their value
+     (options: -nz → hides empty value, -v → verbose)
+     (args: element name or filter pattern)
 tree -> show configuration tree from current node
 help -> show available command
 desc[ription] -> show class desc of current node
@@ -74,18 +78,22 @@ my $desc_sub = sub {
 
 my $ll_sub = sub {
     my $self = shift;
-    my $elt  = shift ;
+    my @raw_args = @_;
+
+    my @desc_opt = qw/check no/;
+
+    my %opt = map { /^-(\w+)/; $1 => 1 } grep { /^-/ } @raw_args;
+    push @desc_opt, hide_empty => 1 if $opt{nz} ;
+    push @desc_opt, verbose    => 1 if $opt{v} ;
+
+    my @args = grep {! /^-/ } @raw_args;
+    push @args, '*' unless @args; # default action is to list all elements
 
     my $obj = $self->{current_node};
-    my $res ;
-    if (defined $elt and $elt =~ /\*/) {
-        $elt =~ s/\*/.*/g;
-        $res = $obj->describe( pattern => qr/^$elt$/, check => 'no' );
-    }
-    else {
-        $res = $obj->describe( element => $elt, check => 'no' );
-    }
-    return $res;
+    map {s/\*/.*/g;} @args ;
+    my $pattern = join ('|',@args);
+
+    return $obj->describe( pattern => qr/^$pattern$/, @desc_opt );
 };
 
 my $cd_sub = sub {
@@ -284,13 +292,11 @@ sub run {
 
     return '' unless $user_cmd =~ /\w/;
 
-    $user_cmd =~ s/^\s+//;
-
-    my ( $action, $args ) = split( m/\s+/, $user_cmd, 2 );
-    $args =~ s/\s+$//g if defined $args;    #cleanup
+    my $re = $RE{delimited}{-delim=>q{'"}};
+    my ( $action, @args ) = ( $user_cmd =~ /((?:[^\s"']|$re)+)/g );
 
     if ( defined $run_dispatch{$action} ) {
-        my $res = eval { $run_dispatch{$action}->( $self, $args ); };
+        my $res = eval { $run_dispatch{$action}->( $self, @args ); };
         print $@ if $@;
         return $res;
     }
@@ -334,7 +340,7 @@ Config::Model::SimpleUI - Simple interface for Config::Model
 
 =head1 VERSION
 
-version 2.095
+version 2.096
 
 =head1 SYNOPSIS
 
@@ -466,13 +472,14 @@ Delete a list or hash element
 
 Display a value
 
-=item ls | ls foo*
+=item ls [ pattern ]
 
 Show elements of current node. Can be used with a shell pattern.
 
-=item ll | ll foo*
+=item ll [-nz] [-v] [ pattern ... ]
 
-Describe elements of current node. Can be used with a shell pattern.
+Describe elements of current node. Can be used with shell patterns or element names.
+Skip empty element with C<-nz> option. Display more information with C<-v> option
 
 =item tree
 
