@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::TermUI;
-$Config::Model::TermUI::VERSION = '2.095';
+$Config::Model::TermUI::VERSION = '2.096';
 use Carp;
 use utf8;      # so literals and identifiers can be in UTF-8
 use v5.12;     # or later to get "unicode_strings" feature
@@ -46,12 +46,17 @@ my $fix_completion_sub = sub {
     return @ret;
 };
 
-# BUG: When doing autocompletion on a hash element with an index
+my $ll_completion_sub = sub {
+    my ( $self, $text, $line, $start ) = @_;
+
+    my @choice = $self->{current_node}->get_element_name;
+    push @choice, '-nz';
+    my @ret = grep( /^$text/, @choice );
+    return @ret;
+};
+
+# BUG: autocompletion does not really on a hash element with an index
 # containing white space (i.e. something like std_id:"abc def",
-# readline's completion insists on adding a white space after :
-# i.e. the run command tries 'std_id: "abd def"' . This fails.  The
-# problem probably revolves around setting a readline variable like
-# rl_completer_word_break_characters, but I do not know which one.
 
 my $cd_completion_sub = sub {
     my ( $self, $text, $line, $start ) = @_;
@@ -91,11 +96,11 @@ my $cd_completion_sub = sub {
             foreach my $idx ( $new_item->fetch_element($elt_name)->fetch_all_indexes ) {
                 # my ($idx) = ($raw_idx =~ /([^\n]{1,40})/ );
                 # $idx .= '...' unless $raw_idx eq $idx ;
-                push @choice, "$elt_name:" . ($idx =~ /[^\w._-]/ ? qq("$idx") : $idx ). ' ';
+                push @choice, "$elt_name:" . ($idx =~ /[^\w._-]/ ? qq("$idx") : $idx );
             }
         }
         else {
-            push @choice, "$elt_name ";
+            push @choice, $elt_name;
         }
     }
 
@@ -110,7 +115,7 @@ my $cd_completion_sub = sub {
 my %completion_dispatch = (
     cd     => $cd_completion_sub,
     desc   => $completion_sub,
-    ll     => $completion_sub,
+    ll     => $ll_completion_sub,
     ls     => $completion_sub,
     check  => $completion_sub,
     fix    => $fix_completion_sub,
@@ -228,7 +233,7 @@ Config::Model::TermUI - Interactive command line interface for cme
 
 =head1 VERSION
 
-version 2.095
+version 2.096
 
 =head1 SYNOPSIS
 
